@@ -9,11 +9,11 @@ from cloudmesh.common.debug import VERBOSE
 from cloudmesh.common.parameter import Parameter
 from cloudmesh.common.util import banner
 from cloudmesh.common.util import path_expand
-from cloudmesh.common.util import sudo_writefile
 from cloudmesh.shell.command import PluginCommand
 from cloudmesh.shell.command import command
 from cloudmesh.shell.command import map_parameters
 from cloudmesh.host.HostCreate import HostCreate
+from cloudmesh.common.sudo import Sudo
 
 
 class HostCommand(PluginCommand):
@@ -294,7 +294,9 @@ class HostCommand(PluginCommand):
 
             names = Parameter.expand(arguments.NAMES)
             port = arguments.port or "8001"
-            ssh_config_output = ""
+            ssh_config_output = f'Host {hostname}\n' \
+                                      f'     HostName {hostname}.local\n' \
+                                      f'     User pi\n\n'
 
             for name in names:
                 service_name = f"autossh-{name}.service"
@@ -302,7 +304,7 @@ class HostCommand(PluginCommand):
                 service_template = "[Unit]\n" \
                                    f"Description=AutoSSH tunnel service to {name} on local port " \
                                    f"{port}\n" \
-                                   "After=network.target\n\n" \
+                                   "After=multi-user.target\n\n" \
                                    "[Service]\n" \
                                    "User=pi\n" \
                                    "Group=pi\n" \
@@ -321,7 +323,7 @@ class HostCommand(PluginCommand):
                                       f'     Port {port}\n\n'
 
                 ssh_config_output += ssh_config_template
-                sudo_writefile(f'/etc/systemd/system/{service_name}',
+                Sudo.writefile(f'/etc/systemd/system/{service_name}',
                                service_template)
                 port = str(int(port) + 1)
 
